@@ -14,30 +14,52 @@
 import os
 import sqlite3
 from builtins import super
-from functools import wraps
-from typing import Optional, List, Dict
-
 from dataclasses import dataclass, field
+from functools import wraps
+from typing import Dict, List, Optional
+
 from peewee import DoesNotExist, SqliteDatabase
 from playhouse.sqliteq import SqliteQueueDatabase
 
-from . import (Accounts, DeviceKeys, DeviceKeys_v1, DeviceTrustState,
-               EncryptedRooms, ForwardedChains, Key, Keys, KeyStore,
-               MegolmInboundSessions, OlmSessions, OutgoingKeyRequests,
-               StoreVersion, SyncTokens)
-from ..crypto import (DeviceStore, GroupSessionStore, InboundGroupSession,
-                      OlmAccount, OlmDevice, OutgoingKeyRequest, Session,
-                      SessionStore, TrustState)
+from ..crypto import (
+    DeviceStore,
+    GroupSessionStore,
+    InboundGroupSession,
+    OlmAccount,
+    OlmDevice,
+    OutgoingKeyRequest,
+    Session,
+    SessionStore,
+    TrustState,
+)
+from . import (
+    Accounts,
+    DeviceKeys,
+    DeviceKeys_v1,
+    DeviceTrustState,
+    EncryptedRooms,
+    ForwardedChains,
+    Key,
+    Keys,
+    KeyStore,
+    MegolmInboundSessions,
+    OlmSessions,
+    OutgoingKeyRequests,
+    StoreVersion,
+    SyncTokens,
+)
 
 
 def use_database(fn):
     """
     Ensure that the correct database context is used for the wrapped function.
     """
+
     @wraps(fn)
     def inner(self, *args, **kwargs):
         with self.database.bind_ctx(self.models):
             return fn(self, *args, **kwargs)
+
     return inner
 
 
@@ -56,6 +78,7 @@ def use_database_atomic(fn):
             else:
                 with self.database.atomic():
                     return fn(self, *args, **kwargs)
+
     return inner
 
 
@@ -73,7 +96,7 @@ class MatrixStore:
         OutgoingKeyRequests,
         StoreVersion,
         Keys,
-        SyncTokens
+        SyncTokens,
     ]
     store_version = 2
 
@@ -91,25 +114,25 @@ class MatrixStore:
             pragmas={
                 "foreign_keys": 1,
                 "secure_delete": 1,
-            }
+            },
         )
 
-    def upgrate_to_v2(self):
+    def upgrade_to_v2(self):
         with self.database.bind_ctx([DeviceKeys_v1]):
-            self.database.drop_tables([
-                DeviceTrustState,
-                DeviceKeys_v1,
-            ], safe=True)
+            self.database.drop_tables(
+                [
+                    DeviceTrustState,
+                    DeviceKeys_v1,
+                ],
+                safe=True,
+            )
 
         with self.database.bind_ctx(self.models):
             self.database.create_tables([DeviceKeys, DeviceTrustState])
         self._update_version(2)
 
     def __post_init__(self):
-        self.database_name = self.database_name or "{}_{}.db".format(
-            self.user_id,
-            self.device_id
-        )
+        self.database_name = self.database_name or f"{self.user_id}_{self.device_id}.db"
         self.database_path = os.path.join(self.store_path, self.database_name)
         self.database = self._create_database()
         self.database.connect()
@@ -118,7 +141,7 @@ class MatrixStore:
 
         # Update the store if it's an old version here.
         if store_version == 1:
-            self.upgrate_to_v2()
+            self.upgrade_to_v2()
 
         with self.database.bind_ctx(self.models):
             self.database.create_tables(self.models)
@@ -126,16 +149,12 @@ class MatrixStore:
     def _get_store_version(self):
         with self.database.bind_ctx([StoreVersion]):
             self.database.create_tables([StoreVersion])
-            v, _ = StoreVersion.get_or_create(
-                defaults={"version": self.store_version}
-            )
+            v, _ = StoreVersion.get_or_create(defaults={"version": self.store_version})
             return v.version
 
     def _update_version(self, new_version):
         with self.database.bind_ctx([StoreVersion]):
-            v, _ = StoreVersion.get_or_create(
-                defaults={"version": new_version}
-            )
+            v, _ = StoreVersion.get_or_create(defaults={"version": new_version})
             v.version = new_version
             v.save()
 
@@ -143,8 +162,7 @@ class MatrixStore:
     def _get_account(self):
         try:
             return Accounts.get(
-                Accounts.user_id == self.user_id,
-                Accounts.device_id == self.device_id
+                Accounts.user_id == self.user_id, Accounts.device_id == self.device_id
             )
         except DoesNotExist:
             return None
@@ -163,11 +181,7 @@ class MatrixStore:
         if not account:
             return None
 
-        return OlmAccount.from_pickle(
-            account.account,
-            self.pickle_key,
-            account.shared
-        )
+        return OlmAccount.from_pickle(account.account, self.pickle_key, account.shared)
 
     @use_database
     def save_account(self, account):
@@ -181,17 +195,16 @@ class MatrixStore:
             user_id=self.user_id,
             device_id=self.device_id,
             shared=account.shared,
-            account=account.pickle(self.pickle_key)
+            account=account.pickle(self.pickle_key),
         ).on_conflict_ignore().execute()
 
         Accounts.update(
             {
                 Accounts.account: account.pickle(self.pickle_key),
-                Accounts.shared: account.shared
+                Accounts.shared: account.shared,
             }
         ).where(
-            (Accounts.user_id == self.user_id)
-            & (Accounts.device_id == self.device_id)
+            (Accounts.user_id == self.user_id) & (Accounts.device_id == self.device_id)
         ).execute()
 
     @use_database
@@ -211,11 +224,7 @@ class MatrixStore:
             return session_store
 
         for s in account.olm_sessions:
-            session = Session.from_pickle(
-                s.session,
-                s.creation_time,
-                self.pickle_key
-            )
+            session = Session.from_pickle(s.session, s.creation_time, self.pickle_key)
             session_store.add(s.sender_key, session)
 
         return session_store
@@ -238,7 +247,7 @@ class MatrixStore:
             session=session.pickle(self.pickle_key),
             session_id=session.id,
             creation_time=session.creation_time,
-            last_usage_date=session.use_time
+            last_usage_date=session.use_time,
         ).execute()
 
     @use_database
@@ -264,7 +273,7 @@ class MatrixStore:
                 s.sender_key,
                 s.room_id,
                 self.pickle_key,
-                [chain.sender_key for chain in s.forwarded_chains]
+                [chain.sender_key for chain in s.forwarded_chains],
             )
             store.add(session)
 
@@ -286,25 +295,16 @@ class MatrixStore:
             fp_key=session.ed25519,
             room_id=session.room_id,
             session=session.pickle(self.pickle_key),
-            session_id=session.id
+            session_id=session.id,
         ).on_conflict_ignore().execute()
 
         MegolmInboundSessions.update(
-            {
-                MegolmInboundSessions.session: session.pickle(
-                    self.pickle_key
-                )
-            }
-        ).where(
-            MegolmInboundSessions.session_id == session.id
-        ).execute()
+            {MegolmInboundSessions.session: session.pickle(self.pickle_key)}
+        ).where(MegolmInboundSessions.session_id == session.id).execute()
 
         # TODO, use replace many here
         for chain in session.forwarding_chain:
-            ForwardedChains.replace(
-                sender_key=chain,
-                session=session.id
-            ).execute()
+            ForwardedChains.replace(sender_key=chain, session=session.id).execute()
 
     @use_database
     def load_device_keys(self):
@@ -320,13 +320,15 @@ class MatrixStore:
             return store
 
         for d in account.device_keys:
-            store.add(OlmDevice(
-                d.user_id,
-                d.device_id,
-                {k.key_type: k.key for k in d.keys},
-                display_name=d.display_name,
-                deleted=d.deleted,
-            ))
+            store.add(
+                OlmDevice(
+                    d.user_id,
+                    d.device_id,
+                    {k.key_type: k.key for k in d.keys},
+                    display_name=d.display_name,
+                    deleted=d.deleted,
+                )
+            )
 
         return store
 
@@ -359,7 +361,7 @@ class MatrixStore:
             return
 
         for idx in range(0, len(rows), 100):
-            data = rows[idx:idx + 100]
+            data = rows[idx : idx + 100]
             DeviceKeys.insert_many(data).on_conflict_ignore().execute()
 
         for user_id, devices_dict in device_keys.items():
@@ -374,11 +376,7 @@ class MatrixStore:
                 d.save()
 
                 for key_type, key in device.keys.items():
-                    Keys.replace(
-                        key_type=key_type,
-                        key=key,
-                        device=d
-                    ).execute()
+                    Keys.replace(key_type=key_type, key=key, device=d).execute()
 
     @use_database
     def load_encrypted_rooms(self):
@@ -408,8 +406,10 @@ class MatrixStore:
         if not account:
             return dict()
 
-        return {request.request_id: OutgoingKeyRequest.from_database(request)
-                for request in account.out_key_requests}
+        return {
+            request.request_id: OutgoingKeyRequest.from_database(request)
+            for request in account.out_key_requests
+        }
 
     @use_database
     def add_outgoing_key_request(self, key_request):
@@ -423,7 +423,7 @@ class MatrixStore:
             session_id=key_request.session_id,
             room_id=key_request.room_id,
             algorithm=key_request.algorithm,
-            account=account
+            account=account,
         ).on_conflict_ignore().execute()
 
     @use_database
@@ -435,7 +435,7 @@ class MatrixStore:
 
         db_key_request = OutgoingKeyRequests.get_or_none(
             OutgoingKeyRequests.request_id == key_request.request_id,
-            OutgoingKeyRequests.account == account
+            OutgoingKeyRequests.account == account,
         )
 
         if db_key_request:
@@ -451,11 +451,10 @@ class MatrixStore:
         data = [(room_id, account) for room_id in rooms]
 
         for idx in range(0, len(data), 400):
-            rows = data[idx:idx + 400]
-            EncryptedRooms.insert_many(rows, fields=[
-                EncryptedRooms.room_id,
-                EncryptedRooms.account
-            ]).on_conflict_ignore().execute()
+            rows = data[idx : idx + 400]
+            EncryptedRooms.insert_many(
+                rows, fields=[EncryptedRooms.room_id, EncryptedRooms.account]
+            ).on_conflict_ignore().execute()
 
     @use_database
     def save_sync_token(self, token):
@@ -464,10 +463,7 @@ class MatrixStore:
         account = self._get_account()
         assert account
 
-        SyncTokens.replace(
-            account=account,
-            token=token
-        ).execute()
+        SyncTokens.replace(account=account, token=token).execute()
 
     @use_database
     def load_sync_token(self):
@@ -639,29 +635,14 @@ class DefaultStore(MatrixStore):
     def __post_init__(self):
         super().__post_init__()
 
-        trust_file_path = "{}_{}.trusted_devices".format(
-            self.user_id,
-            self.device_id
-        )
-        self.trust_db = KeyStore(
-            os.path.join(self.store_path, trust_file_path)
-        )
+        trust_file_path = f"{self.user_id}_{self.device_id}.trusted_devices"
+        self.trust_db = KeyStore(os.path.join(self.store_path, trust_file_path))
 
-        blacklist_file_path = "{}_{}.blacklisted_devices".format(
-            self.user_id,
-            self.device_id
-        )
-        self.blacklist_db = KeyStore(
-            os.path.join(self.store_path, blacklist_file_path)
-        )
+        blacklist_file_path = f"{self.user_id}_{self.device_id}.blacklisted_devices"
+        self.blacklist_db = KeyStore(os.path.join(self.store_path, blacklist_file_path))
 
-        ignore_file_path = "{}_{}.ignored_devices".format(
-            self.user_id,
-            self.device_id
-        )
-        self.ignore_db = KeyStore(
-            os.path.join(self.store_path, ignore_file_path)
-        )
+        ignore_file_path = f"{self.user_id}_{self.device_id}.ignored_devices"
+        self.ignore_db = KeyStore(os.path.join(self.store_path, ignore_file_path))
 
     def blacklist_device(self, device):
         # type: (OlmDevice) -> bool
@@ -809,7 +790,7 @@ class SqliteStore(MatrixStore):
             return DeviceKeys.get(
                 DeviceKeys.user_id == device.user_id,
                 DeviceKeys.device_id == device.id,
-                DeviceKeys.account == acc
+                DeviceKeys.account == acc,
             )
         except DoesNotExist:
             return None
@@ -823,10 +804,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.verified
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.verified).execute()
 
         device.trust_state = TrustState.verified
 
@@ -841,10 +819,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.unset
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.unset).execute()
 
         device.trust_state = TrustState.unset
 
@@ -874,10 +849,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.blacklisted
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.blacklisted).execute()
 
         device.trust_state = TrustState.blacklisted
 
@@ -892,10 +864,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.unset
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.unset).execute()
 
         device.trust_state = TrustState.unset
 
@@ -925,10 +894,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.ignored
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.ignored).execute()
 
         device.trust_state = TrustState.ignored
 
@@ -943,10 +909,7 @@ class SqliteStore(MatrixStore):
         d = self._get_device(device)
         assert d
 
-        DeviceTrustState.replace(
-            device=d,
-            state=TrustState.unset
-        ).execute()
+        DeviceTrustState.replace(device=d, state=TrustState.unset).execute()
 
         device.trust_state = TrustState.unset
 
@@ -975,21 +938,18 @@ class SqliteStore(MatrixStore):
         values = [item for sublist in tuple_values for item in sublist]
 
         for idx in range(0, len(values), 300):
-            data = values[idx:idx + 300]
+            data = values[idx : idx + 300]
 
             query_string = (
                 "SELECT devicekeys.* from devicekeys "
                 "JOIN accounts ON devicekeys.account_id=accounts.id "
                 "WHERE accounts.id == ? AND "
                 "(devicekeys.user_id, devicekeys.device_id) IN "
-                "(VALUES {})".format(",".join(["(?, ?)"] * (len(data) // 2))))
-
-            query = DeviceKeys.raw(
-                query_string,
-                account.id,
-                *data
+                f"(VALUES {','.join(['(?, ?)'] * (len(data) // 2))})"
             )
 
+            query = DeviceKeys.raw(query_string, account.id, *data)
+
             device_ids += [device_key.id for device_key in query]
 
         return device_ids
@@ -1008,16 +968,14 @@ class SqliteStore(MatrixStore):
             device_ids = self._legacy_get_device_ids(acc, devices)
 
         rows = [
-            {
-                "device_id": device_id,
-                "state": TrustState.ignored
-            } for device_id in device_ids
+            {"device_id": device_id, "state": TrustState.ignored}
+            for device_id in device_ids
         ]
 
         assert len(rows) == len(devices)
 
         for idx in range(0, len(rows), 100):
-            trust_data = rows[idx:idx + 100]
+            trust_data = rows[idx : idx + 100]
             DeviceTrustState.replace_many(trust_data).execute()
 
         for device in devices:
@@ -1053,14 +1011,16 @@ class SqliteStore(MatrixStore):
             except IndexError:
                 trust_state = TrustState.unset
 
-            store.add(OlmDevice(
-                d.user_id,
-                d.device_id,
-                {k.key_type: k.key for k in d.keys},
-                display_name=d.display_name,
-                deleted=d.deleted,
-                trust_state=trust_state
-            ))
+            store.add(
+                OlmDevice(
+                    d.user_id,
+                    d.device_id,
+                    {k.key_type: k.key for k in d.keys},
+                    display_name=d.display_name,
+                    deleted=d.deleted,
+                    trust_state=trust_state,
+                )
+            )
 
         return store
 
@@ -1088,5 +1048,5 @@ class SqliteMemoryStore(SqliteStore):
             pragmas={
                 "foreign_keys": 1,
                 "secure_delete": 1,
-            }
+            },
         )
